@@ -46,10 +46,10 @@ def from_image_file(img_path: str, **kwargs) -> str:
 
 
 def from_clipboard(**kwargs) -> str:
-	with ImageGrab.grabclipboard() as img:
-		if not img:
-			raise ValueError('Image not found in clipboard')
-		return from_image(img, **kwargs)
+	img = ImageGrab.grabclipboard()
+	if not img:
+		raise ValueError('Image not found in clipboard')
+	return from_image(img, **kwargs)
 
 
 def from_image(img: Image, columns=120, width_ratio=2.5, char=None, mode: Modes=Modes.TERMINAL, back: Back = None, debug=False) -> str:
@@ -109,6 +109,19 @@ def to_terminal(ascii_art: str) -> None:
 	print(ascii_art)
 
 
+def to_html_file(path: str, art: str, styles: str = 'background:black; font-size: 11px;') -> None:
+	with open(path, 'w') as f:
+		html = f"""<!DOCTYPE html>
+<head>
+	<title>ASCII art</title>
+</head>
+<body>
+	<pre style="{styles}">{art}</pre>
+</body>
+</html>"""
+		f.write(html)
+
+
 def convert_color(rgb: list, brightness: float) -> int:
 	min_distance = 2
 	index = 0
